View a markdown version of this page

HealthOmics contoh menggunakan AWS CLI - AWS Command Line Interface

Terjemahan disediakan oleh mesin penerjemah. Jika konten terjemahan yang diberikan bertentangan dengan versi bahasa Inggris aslinya, utamakan versi bahasa Inggris.

HealthOmics contoh menggunakan AWS CLI

Contoh kode berikut menunjukkan cara melakukan tindakan dan menerapkan skenario umum dengan menggunakan AWS Command Line Interface with HealthOmics.

Tindakan merupakan kutipan kode dari program yang lebih besar dan harus dijalankan dalam konteks. Sementara tindakan menunjukkan cara memanggil fungsi layanan individual, Anda dapat melihat tindakan dalam konteks dalam skenario terkait.

Setiap contoh menyertakan tautan ke kode sumber lengkap, di mana Anda dapat menemukan instruksi tentang cara mengatur dan menjalankan kode dalam konteks.

Tindakan

Contoh kode berikut menunjukkan cara menggunakanabort-multipart-read-set-upload.

AWS CLI

Untuk menghentikan pengunggahan kumpulan baca multibagian

abort-multipart-read-set-uploadContoh berikut menghentikan unggahan kumpulan baca multibagian ke penyimpanan HealthOmics urutan Anda.

aws omics abort-multipart-read-set-upload \ --sequence-store-id 0123456789 \ --upload-id 1122334455

Perintah ini tidak menghasilkan output.

Untuk informasi selengkapnya, lihat Mengunggah langsung ke penyimpanan urutan di Panduan AWS HealthOmics Pengguna.

Contoh kode berikut menunjukkan cara menggunakanaccept-share.

AWS CLI

Untuk menerima bagian data penyimpanan analitik

accept-shareContoh berikut menerima bagian data penyimpanan HealthOmics analitik.

aws omics accept-share \ --share-id "495c21bedc889d07d0ab69d710a6841e-dd75ab7a1a9c384fa848b5bd8e5a7e0a"

Output:

{ "status": "ACTIVATING" }

Untuk informasi selengkapnya, lihat Cross-account berbagi di Panduan AWS HealthOmics Pengguna.

  • Untuk detail API, lihat AcceptShare di Refer AWS CLI ensi Perintah.

Contoh kode berikut menunjukkan cara menggunakanbatch-delete-read-set.

AWS CLI

Untuk menghapus beberapa set baca

batch-delete-read-setContoh berikut menghapus dua set baca.

aws omics batch-delete-read-set \ --sequence-store-id 1234567890 \ --ids 1234567890 0123456789

Jika ada kesalahan saat menghapus salah satu set baca yang ditentukan, layanan mengembalikan daftar kesalahan.

{ "errors": [ { "code": "", "id": "0123456789", "message": "The specified readset does not exist." } ] }

Untuk informasi selengkapnya, lihat Peny impanan Omics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakancancel-annotation-import-job.

AWS CLI

Untuk membatalkan pekerjaan impor anotasi

cancel-annotation-import-jobContoh berikut membatalkan pekerjaan impor anotasi dengan ID04f57618-xmpl-4fd0-9349-e5a85aefb997.

aws omics cancel-annotation-import-job \ --job-id 04f57618-xmpl-4fd0-9349-e5a85aefb997

Untuk informasi selengkapnya, lihat Omics Analytics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakancancel-run.

AWS CLI

Untuk membatalkan lari

cancel-runContoh berikut membatalkan run dengan ID1234567.

aws omics cancel-run \ --id 1234567

Untuk informasi selengkapnya, lihat Menjalankan siklus hidup dalam alur kerja di Panduan AWS HealthOmics Pengguna.

  • Untuk detail API, lihat CancelRun di Refer AWS CLI ensi Perintah.

Contoh kode berikut menunjukkan cara menggunakancancel-variant-import-job.

AWS CLI

Untuk membatalkan pekerjaan impor varian

cancel-variant-import-jobContoh berikut membatalkan pekerjaan impor varian dengan ID69cb65d6-xmpl-4a4a-9025-4565794b684e.

aws omics cancel-variant-import-job \ --job-id 69cb65d6-xmpl-4a4a-9025-4565794b684e

Untuk informasi selengkapnya, lihat Omics Analytics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakancomplete-multipart-read-set-upload.

AWS CLI

Untuk menyimpulkan unggahan multipart setelah Anda mengunggah semua komponen.

complete-multipart-read-set-uploadContoh berikut menyimpulkan unggahan multipart ke penyimpanan urutan setelah semua komponen telah diunggah.

aws omics complete-multipart-read-set-upload \ --sequence-store-id 0123456789 \ --upload-id 1122334455 \ --parts '[{"checksum":"gaCBQMe+rpCFZxLpoP6gydBoXaKKDA/Vobh5zBDb4W4=","partNumber":1,"partSource":"SOURCE1"}]'

Output:

{ "readSetId": "0000000001" "readSetId": "0000000002" "readSetId": "0000000003" }

Untuk informasi selengkapnya, lihat Mengunggah langsung ke penyimpanan urutan di Panduan AWS HealthOmics Pengguna.

Contoh kode berikut menunjukkan cara menggunakancreate-annotation-store-version.

AWS CLI

Untuk membuat versi baru dari toko anotasi

create-annotation-store-versionContoh berikut membuat versi baru dari penyimpanan anotasi.

aws omics create-annotation-store-version \ --name my_annotation_store \ --version-name my_version

Output:

{ "creationTime": "2023-07-21T17:15:49.251040+00:00", "id": "3b93cdef69d2", "name": "my_annotation_store", "reference": { "referenceArn": "arn:aws:omics:us-west-2:555555555555:referenceStore/6505293348/reference/5987565360" }, "status": "CREATING", "versionName": "my_version" }

Untuk informasi selengkapnya, lihat Membuat versi baru penyimpanan anotasi di Panduan AWS HealthOmics Pengguna.

Contoh kode berikut menunjukkan cara menggunakancreate-annotation-store.

AWS CLI

Contoh 1: Untuk membuat penyimpanan anotasi VCF

create-annotation-storeContoh berikut membuat penyimpanan anotasi format VCF.

aws omics create-annotation-store \ --name my_ann_store \ --store-format VCF \ --reference referenceArn=arn:aws:omics:us-west-2:123456789012:referenceStore/1234567890/reference/1234567890

Output:

{ "creationTime": "2022-11-23T22:48:39.226492Z", "id": "0a91xmplc71f", "name": "my_ann_store", "reference": { "referenceArn": "arn:aws:omics:us-west-2:123456789012:referenceStore/1234567890/reference/1234567890" }, "status": "CREATING", "storeFormat": "VCF" }

Contoh 2: Untuk membuat penyimpanan anotasi TSV

create-annotation-storeContoh berikut membuat penyimpanan anotasi format TSV.

aws omics create-annotation-store \ --name tsv_ann_store \ --store-format TSV \ --reference referenceArn=arn:aws:omics:us-west-2:123456789012:referenceStore/1234567890/reference/1234567890 \ --store-options file://tsv-store-options.json

tsv-store-options.jsonmengkonfigurasi opsi format untuk anotasi.

{ "tsvStoreOptions": { "annotationType": "CHR_START_END_ZERO_BASE", "formatToHeader": { "CHR": "chromosome", "START": "start", "END": "end" }, "schema": [ { "chromosome": "STRING" }, { "start": "LONG" }, { "end": "LONG" }, { "name": "STRING" } ] } }

Output:

{ "creationTime": "2022-11-30T01:28:08.525586Z", "id": "861cxmpl96b0", "name": "tsv_ann_store", "reference": { "referenceArn": "arn:aws:omics:us-west-2:123456789012:referenceStore/1234567890/reference/1234567890" }, "status": "CREATING", "storeFormat": "TSV", "storeOptions": { "tsvStoreOptions": { "annotationType": "CHR_START_END_ZERO_BASE", "formatToHeader": { "CHR": "chromosome", "END": "end", "START": "start" }, "schema": [ { "chromosome": "STRING" }, { "start": "LONG" }, { "end": "LONG" }, { "name": "STRING" } ] } } }

Untuk informasi selengkapnya, lihat Omics Analytics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakancreate-multipart-read-set-upload.

AWS CLI

Untuk memulai unggahan kumpulan baca multibagian.

create-multipart-read-set-uploadContoh berikut memulai upload set baca multipart.

aws omics create-multipart-read-set-upload \ --sequence-store-id 0123456789 \ --name HG00146 \ --source-file-type FASTQ \ --subject-id mySubject\ --sample-id mySample\ --description "FASTQ for HG00146"\ --generated-from "1000 Genomes"

Output:

{ "creationTime": "2022-07-13T23:25:20Z", "description": "FASTQ for HG00146", "generatedFrom": "1000 Genomes", "name": "HG00146", "sampleId": "mySample", "sequenceStoreId": "0123456789", "sourceFileType": "FASTQ", "subjectId": "mySubject", "uploadId": "1122334455" }

Untuk informasi selengkapnya, lihat Mengunggah langsung ke penyimpanan urutan di Panduan AWS HealthOmics Pengguna.

Contoh kode berikut menunjukkan cara menggunakancreate-reference-store.

AWS CLI

Untuk membuat toko referensi

create-reference-storeContoh berikut membuat penyimpanan referensimy-ref-store.

aws omics create-reference-store \ --name my-ref-store

Output:

{ "arn": "arn:aws:omics:us-west-2:123456789012:referenceStore/1234567890", "creationTime": "2022-11-22T22:13:25.947Z", "id": "1234567890", "name": "my-ref-store" }

Untuk informasi selengkapnya, lihat Peny impanan Omics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakancreate-run-group.

AWS CLI

Untuk membuat grup yang dijalankan

create-run-groupContoh berikut membuat grup run bernamacram-converter.

aws omics create-run-group \ --name cram-converter \ --max-cpus 20 \ --max-gpus 10 \ --max-duration 600 \ --max-runs 5

Output:

{ "arn": "arn:aws:omics:us-west-2:123456789012:runGroup/1234567", "id": "1234567", "tags": {} }

Untuk informasi selengkapnya, lihat Membuat grup run di Panduan AWS HealthOmics Pengguna.

Contoh kode berikut menunjukkan cara menggunakancreate-sequence-store.

AWS CLI

Untuk membuat penyimpanan urutan

create-sequence-storeContoh berikut membuat penyimpan urutan.

aws omics create-sequence-store \ --name my-seq-store

Output:

{ "arn": "arn:aws:omics:us-west-2:123456789012:sequenceStore/1234567890", "creationTime": "2022-11-23T01:24:33.629Z", "id": "1234567890", "name": "my-seq-store" }

Untuk informasi selengkapnya, lihat Peny impanan Omics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakancreate-share.

AWS CLI

Untuk membuat bagian dari toko HealthOmics analitik

create-shareContoh berikut menunjukkan cara membuat bagian dari toko HealthOmics analitik yang dapat diterima oleh pelanggan di luar akun.

aws omics create-share \ --resource-arn "arn:aws:omics:us-west-2:555555555555:variantStore/omics_dev_var_store" \ --principal-subscriber "123456789012" \ --name "my_Share-123"

Output:

{ "shareId": "495c21bedc889d07d0ab69d710a6841e-dd75ab7a1a9c384fa848b5bd8e5a7e0a", "name": "my_Share-123", "status": "PENDING" }

Untuk informasi selengkapnya, lihat Cross-acount berbagi di Panduan AWS HealthOmics Pengguna.

  • Untuk detail API, lihat CreateShare di Refer AWS CLI ensi Perintah.

Contoh kode berikut menunjukkan cara menggunakancreate-variant-store.

AWS CLI

Untuk membuat toko varian

create-variant-storeContoh berikut membuat toko varian bernamamy_var_store.

aws omics create-variant-store \ --name my_var_store \ --reference referenceArn=arn:aws:omics:us-west-2:123456789012:referenceStore/1234567890/reference/1234567890

Output:

{ "creationTime": "2022-11-23T22:09:07.534499Z", "id": "02dexmplcfdd", "name": "my_var_store", "reference": { "referenceArn": "arn:aws:omics:us-west-2:123456789012:referenceStore/1234567890/reference/1234567890" }, "status": "CREATING" }

Untuk informasi selengkapnya, lihat Omics Analytics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakancreate-workflow.

AWS CLI

Untuk membuat alur kerja

create-workflowContoh berikut membuat alur kerja WDL.

aws omics create-workflow \ --name cram-converter \ --engine WDL \ --definition-zip fileb://workflow-crambam.zip \ --parameter-template file://workflow-params.json

workflow-crambam.zipadalah arsip ZIP yang berisi definisi alur kerja. workflow-params.jsonmendefinisikan parameter runtime untuk alur kerja.

{ "ref_fasta" : { "description": "Reference genome fasta file", "optional": false }, "ref_fasta_index" : { "description": "Index of the reference genome fasta file", "optional": false }, "ref_dict" : { "description": "dictionary file for 'ref_fasta'", "optional": false }, "input_cram" : { "description": "The Cram file to convert to BAM", "optional": false }, "sample_name" : { "description": "The name of the input sample, used to name the output BAM", "optional": false } }

Output:

{ "arn": "arn:aws:omics:us-west-2:123456789012:workflow/1234567", "id": "1234567", "status": "CREATING", "tags": {} }

Untuk informasi selengkapnya, lihat Membuat alur kerja pribadi di Panduan AWS HealthOmics Pengguna.

Contoh kode berikut menunjukkan cara menggunakandelete-annotation-store-versions.

AWS CLI

Untuk menghapus versi penyimpanan anotasi

delete-annotation-store-versionsContoh berikut menghapus versi penyimpanan anotasi.

aws omics delete-annotation-store-versions \ --name my_annotation_store \ --versions my_version

Output:

{ "errors": [] }

Untuk informasi selengkapnya, lihat Membuat versi baru penyimpanan anotasi di Panduan AWS HealthOmics Pengguna.

Contoh kode berikut menunjukkan cara menggunakandelete-annotation-store.

AWS CLI

Untuk menghapus penyimpanan anotasi

delete-annotation-storeContoh berikut menghapus toko anotasi bernamamy_vcf_store.

aws omics delete-annotation-store \ --name my_vcf_store

Output:

{ "status": "DELETING" }

Untuk informasi selengkapnya, lihat Omics Analytics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakandelete-reference-store.

AWS CLI

Untuk menghapus penyimpanan referensi

delete-reference-storeContoh berikut menghapus penyimpanan referensi dengan ID1234567890.

aws omics delete-reference-store \ --id 1234567890

Untuk informasi selengkapnya, lihat Peny impanan Omics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakandelete-reference.

AWS CLI

Untuk menghapus referensi

delete-referenceContoh berikut menghapus referensi.

aws omics delete-reference \ --reference-store-id 1234567890 \ --id 1234567890

Untuk informasi selengkapnya, lihat Peny impanan Omics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakandelete-run-group.

AWS CLI

Untuk menghapus grup yang dijalankan

delete-run-groupContoh berikut menghapus grup run dengan ID1234567.

aws omics delete-run-group \ --id 1234567

Untuk informasi selengkapnya, lihat Menghapus grup run dan jalankan di Panduan AWS HealthOmics Pengguna.

Contoh kode berikut menunjukkan cara menggunakandelete-run.

AWS CLI

Untuk menghapus alur kerja yang dijalankan

delete-runContoh berikut menghapus run dengan ID1234567.

aws omics delete-run \ --id 1234567

Untuk informasi selengkapnya, lihat Menghapus grup run dan jalankan di Panduan AWS HealthOmics Pengguna.

  • Untuk detail API, lihat DeleteRun di Refer AWS CLI ensi Perintah.

Contoh kode berikut menunjukkan cara menggunakandelete-sequence-store.

AWS CLI

Untuk menghapus penyimpanan urutan

delete-sequence-storeContoh berikut menghapus urutan penyimpanan dengan ID1234567890.

aws omics delete-sequence-store \ --id 1234567890

Untuk informasi selengkapnya, lihat Peny impanan Omics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakandelete-share.

AWS CLI

Untuk menghapus bagian data HealthOmics analitik

delete-shareContoh berikut menghapus bagian data analitik lintas akun.

aws omics delete-share \ --share-id "495c21bedc889d07d0ab69d710a6841e-dd75ab7a1a9c384fa848b5bd8e5a7e0a"

Output:

{ "status": "DELETING" }

Untuk informasi selengkapnya, lihat Cross-account berbagi di Panduan AWS HealthOmics Pengguna.

  • Untuk detail API, lihat DeleteShare di Refer AWS CLI ensi Perintah.

Contoh kode berikut menunjukkan cara menggunakandelete-variant-store.

AWS CLI

Untuk menghapus penyimpanan varian

delete-variant-storeContoh berikut menghapus toko varian bernamamy_var_store.

aws omics delete-variant-store \ --name my_var_store

Output:

{ "status": "DELETING" }

Untuk informasi selengkapnya, lihat Omics Analytics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakandelete-workflow.

AWS CLI

Untuk menghapus alur kerja

delete-workflowContoh berikut menghapus alur kerja dengan ID1234567.

aws omics delete-workflow \ --id 1234567

Untuk informasi selengkapnya, lihat Mengh apus alur kerja pribadi di Panduan AWS HealthOmics Pengguna.

Contoh kode berikut menunjukkan cara menggunakanget-annotation-import-job.

AWS CLI

Untuk melihat pekerjaan impor anotasi

get-annotation-import-jobContoh berikut mendapatkan detail tentang pekerjaan impor anotasi.

aws omics get-annotation-import-job \ --job-id 984162c7-xmpl-4d23-ab47-286f7950bfbf

Output:

{ "creationTime": "2022-11-30T01:40:11.017746Z", "destinationName": "tsv_ann_store", "id": "984162c7-xmpl-4d23-ab47-286f7950bfbf", "items": [ { "jobStatus": "COMPLETED", "source": "s3://omics-artifacts-01d6xmpl4e72dd32/targetedregions.bed.gz" } ], "roleArn": "arn:aws:iam::123456789012:role/omics-service-role-serviceRole-W8O1XMPL7QZ", "runLeftNormalization": false, "status": "COMPLETED", "updateTime": "2022-11-30T01:42:39.134009Z" }

Untuk informasi selengkapnya, lihat Omics Analytics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanget-annotation-store-version.

AWS CLI

Untuk mengambil metadata untuk versi penyimpanan anotasi

get-annotation-store-versionContoh berikut mengambil metadata untuk versi penyimpanan anotasi yang diminta.

aws omics get-annotation-store-version \ --name my_annotation_store \ --version-name my_version

Output:

{ "storeId": "4934045d1c6d", "id": "2a3f4a44aa7b", "status": "ACTIVE", "versionArn": "arn:aws:omics:us-west-2:555555555555:annotationStore/my_annotation_store/version/my_version", "name": "my_annotation_store", "versionName": "my_version", "creationTime": "2023-07-21T17:15:49.251040+00:00", "updateTime": "2023-07-21T17:15:56.434223+00:00", "statusMessage": "", "versionSizeBytes": 0 }

Untuk informasi selengkapnya, lihat Membuat versi baru penyimpanan anotasi di Panduan AWS HealthOmics Pengguna.

Contoh kode berikut menunjukkan cara menggunakanget-annotation-store.

AWS CLI

Untuk melihat toko anotasi

get-annotation-storeContoh berikut mendapatkan detail tentang toko anotasi bernamamy_ann_store.

aws omics get-annotation-store \ --name my_ann_store

Output:

{ "creationTime": "2022-11-23T22:48:39.226492Z", "id": "0a91xmplc71f", "name": "my_ann_store", "reference": { "referenceArn": "arn:aws:omics:us-west-2:123456789012:referenceStore/1234567890/reference/1234567890" }, "status": "CREATING", "storeArn": "arn:aws:omics:us-west-2:123456789012:annotationStore/my_ann_store", "storeFormat": "VCF", "storeSizeBytes": 0, "tags": {} }

Untuk informasi selengkapnya, lihat Omics Analytics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanget-read-set-activation-job.

AWS CLI

Untuk melihat pekerjaan aktivasi set baca

get-read-set-activation-jobContoh berikut mendapatkan detail tentang pekerjaan aktivasi set baca.

aws omics get-read-set-activation-job \ --sequence-store-id 1234567890 \ --id 1234567890

Output:

{ "completionTime": "2022-12-06T22:33:42.828Z", "creationTime": "2022-12-06T22:32:45.213Z", "id": "1234567890", "sequenceStoreId": "1234567890", "sources": [ { "readSetId": "1234567890", "status": "FINISHED", "statusMessage": "No activation needed as read set is already in ACTIVATING or ACTIVE state." } ], "status": "COMPLETED", "statusMessage": "The job completed successfully." }

Untuk informasi selengkapnya, lihat Peny impanan Omics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanget-read-set-export-job.

AWS CLI

Untuk melihat pekerjaan ekspor set baca

get-read-set-export-jobContoh berikut mendapatkan detail tentang pekerjaan ekspor set baca.

aws omics get-read-set-export-job \ --sequence-store-id 1234567890 \ --id 1234567890

Output:

{ "completionTime": "2022-12-06T22:39:14.491Z", "creationTime": "2022-12-06T22:37:18.612Z", "destination": "s3://omics-artifacts-01d6xmpl4e72dd32/read-set-export/", "id": "1234567890", "sequenceStoreId": "1234567890", "status": "COMPLETED", "statusMessage": "The job is submitted and will start soon." }

Untuk informasi selengkapnya, lihat Peny impanan Omics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanget-read-set-import-job.

AWS CLI

Untuk melihat pekerjaan impor kumpulan baca

get-read-set-import-jobContoh berikut mendapatkan detail tentang pekerjaan impor set baca.

aws omics get-read-set-import-job \ --sequence-store-id 1234567890 \ --id 1234567890

Output:

{ "creationTime": "2022-11-23T01:36:38.158Z", "id": "1234567890", "roleArn": "arn:aws:iam::123456789012:role/omics-service-role-serviceRole-W8O1XMPL7QZ", "sequenceStoreId": "1234567890", "sources": [ { "name": "HG00100", "referenceArn": "arn:aws:omics:us-west-2:123456789012:referenceStore/1234567890/reference/1234567890", "sampleId": "bam-sample", "sourceFileType": "BAM", "sourceFiles": { "source1": "s3://omics-artifacts-01d6xmpl4e72dd32/HG00100.chrom20.ILLUMINA.bwa.GBR.low_coverage.20101123.bam", "source2": "" }, "status": "IN_PROGRESS", "statusMessage": "The source job is currently in progress.", "subjectId": "bam-subject", "tags": { "aws:omics:sampleId": "bam-sample", "aws:omics:subjectId": "bam-subject" } }, { "name": "HG00146", "referenceArn": "arn:aws:omics:us-west-2:123456789012:referenceStore/1234567890/reference/1234567890", "sampleId": "fastq-sample", "sourceFileType": "FASTQ", "sourceFiles": { "source1": "s3://omics-artifacts-01d6xmpl4e72dd32/SRR233106_1.filt.fastq.gz", "source2": "s3://omics-artifacts-01d6xmpl4e72dd32/SRR233106_2.filt.fastq.gz" }, "status": "IN_PROGRESS", "statusMessage": "The source job is currently in progress.", "subjectId": "fastq-subject", "tags": { "aws:omics:sampleId": "fastq-sample", "aws:omics:subjectId": "fastq-subject" } }, { "name": "HG00096", "referenceArn": "arn:aws:omics:us-west-2:123456789012:referenceStore/1234567890/reference/1234567890", "sampleId": "cram-sample", "sourceFileType": "CRAM", "sourceFiles": { "source1": "s3://omics-artifacts-01d6xmpl4e72dd32/HG00096.alt_bwamem_GRCh38DH.20150718.GBR.low_coverage.cram", "source2": "" }, "status": "IN_PROGRESS", "statusMessage": "The source job is currently in progress.", "subjectId": "cram-subject", "tags": { "aws:omics:sampleId": "cram-sample", "aws:omics:subjectId": "cram-subject" } } ], "status": "IN_PROGRESS", "statusMessage": "The job is currently in progress." }

Untuk informasi selengkapnya, lihat Peny impanan Omics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanget-read-set-metadata.

AWS CLI

Untuk melihat kumpulan baca

get-read-set-metadataContoh berikut mendapatkan detail tentang file set baca.

aws omics get-read-set-metadata \ --sequence-store-id 1234567890 \ --id 1234567890

Output:

{ "arn": "arn:aws:omics:us-west-2:123456789012:sequenceStore/1234567890/readSet/1234567890", "creationTime": "2022-11-23T21:55:00.515Z", "fileType": "FASTQ", "files": { "source1": { "contentLength": 310054739, "partSize": 104857600, "totalParts": 3 }, "source2": { "contentLength": 307846621, "partSize": 104857600, "totalParts": 3 } }, "id": "1234567890", "name": "HG00146", "referenceArn": "arn:aws:omics:us-west-2:123456789012:referenceStore/1234567890/reference/1234567890", "sampleId": "fastq-sample", "sequenceInformation": { "alignment": "UNALIGNED", "totalBaseCount": 677717384, "totalReadCount": 8917334 }, "sequenceStoreId": "1234567890", "status": "ACTIVE", "subjectId": "fastq-subject" }

Untuk informasi selengkapnya, lihat Peny impanan Omics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanget-read-set.

AWS CLI

Untuk mengunduh kumpulan baca

get-read-setContoh berikut mengunduh bagian 3 dari kumpulan baca sebagai1234567890.3.bam.

aws omics get-read-set \ --sequence-store-id 1234567890 \ --id 1234567890 \ --part-number 3 1234567890.3.bam

Untuk informasi selengkapnya, lihat Peny impanan Omics di Panduan Pengembang Amazon Omics.

  • Untuk detail API, lihat GetReadSet di Refer AWS CLI ensi Perintah.

Contoh kode berikut menunjukkan cara menggunakanget-reference-import-job.

AWS CLI

Untuk melihat pekerjaan impor referensi

Contoh get-reference-import-job contoh berikut mendapatkan detail tentang pekerjaan impor referensi.

aws omics get-reference-import-job \ --reference-store-id 1234567890 \ --id 1234567890

Output:

{ "creationTime": "2022-11-22T22:25:41.124Z", "id": "1234567890", "referenceStoreId": "1234567890", "roleArn": "arn:aws:iam::123456789012:role/omics-service-role-serviceRole-W8O1XMPL7QZ", "sources": [ { "name": "assembly-38", "sourceFile": "s3://omics-artifacts-01d6xmpl4e72dd32/Homo_sapiens_assembly38.fasta", "status": "IN_PROGRESS", "statusMessage": "The source job is currently in progress." } ], "status": "IN_PROGRESS", "statusMessage": "The job is currently in progress." }

Untuk informasi selengkapnya, lihat Peny impanan Omics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanget-reference-metadata.

AWS CLI

Untuk melihat referensi

get-reference-metadataContoh berikut mendapatkan detail tentang referensi.

aws omics get-reference-metadata \ --reference-store-id 1234567890 \ --id 1234567890

Output:

{ "arn": "arn:aws:omics:us-west-2:123456789012:referenceStore/1234567890/reference/1234567890", "creationTime": "2022-11-22T22:27:09.033Z", "files": { "index": { "contentLength": 160928, "partSize": 104857600, "totalParts": 1 }, "source": { "contentLength": 3249912778, "partSize": 104857600, "totalParts": 31 } }, "id": "1234567890", "md5": "7ff134953dcca8c8997453bbb80b6b5e", "name": "assembly-38", "referenceStoreId": "1234567890", "status": "ACTIVE", "updateTime": "2022-11-22T22:27:09.033Z" }

Untuk informasi selengkapnya, lihat Peny impanan Omics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanget-reference-store.

AWS CLI

Untuk melihat toko referensi

get-reference-storeContoh berikut mendapatkan detail tentang toko referensi.

aws omics get-reference-store \ --id 1234567890

Output:

{ "arn": "arn:aws:omics:us-west-2:123456789012:referenceStore/1234567890", "creationTime": "2022-09-23T23:27:20.364Z", "id": "1234567890", "name": "my-rstore-0" }

Untuk informasi selengkapnya, lihat Peny impanan Omics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanget-reference.

AWS CLI

Untuk mengunduh referensi genom

get-referenceContoh berikut mengunduh bagian 1 genom sebagaihg38.1.fa.

aws omics get-reference \ --reference-store-id 1234567890 \ --id 1234567890 \ --part-number 1 hg38.1.fa

Untuk informasi selengkapnya, lihat Peny impanan Omics di Panduan Pengembang Amazon Omics.

  • Untuk detail API, lihat GetReference di Refer AWS CLI ensi Perintah.

Contoh kode berikut menunjukkan cara menggunakanget-run-group.

AWS CLI

Untuk melihat grup yang dijalankan

get-run-groupContoh berikut mendapatkan detail tentang grup run.

aws omics get-run-group \ --id 1234567

Output:

{ "arn": "arn:aws:omics:us-west-2:123456789012:runGroup/1234567", "creationTime": "2022-12-01T00:58:42.915219Z", "id": "1234567", "maxCpus": 20, "maxDuration": 600, "name": "cram-convert", "tags": {} }

Untuk informasi selengkapnya, lihat Membuat grup run di Panduan AWS HealthOmics Pengguna.

  • Untuk detail API, lihat GetRunGroup di Refer AWS CLI ensi Perintah.

Contoh kode berikut menunjukkan cara menggunakanget-run-task.

AWS CLI

Untuk melihat tugas

get-run-taskContoh berikut mendapatkan detail tentang tugas alur kerja.

aws omics get-run-task \ --id 1234567 \ --task-id 1234567

Output:

{ "cpus": 1, "creationTime": "2022-11-30T23:13:00.718651Z", "logStream": "arn:aws:logs:us-west-2:123456789012:log-group:/aws/omics/WorkflowLog:log-stream:run/1234567/task/1234567", "memory": 15, "name": "CramToBamTask", "startTime": "2022-11-30T23:17:47.016Z", "status": "COMPLETED", "stopTime": "2022-11-30T23:18:21.503Z", "taskId": "1234567" }

Untuk informasi selengkapnya, lihat Siklus hidup HealthOmics tugas dalam proses di Panduan AWS HealthOmics Pengguna.

  • Untuk detail API, lihat GetRunTask di Refer AWS CLI ensi Perintah.

Contoh kode berikut menunjukkan cara menggunakanget-run.

AWS CLI

Untuk melihat alur kerja yang dijalankan

get-runContoh berikut mendapatkan detail tentang alur kerja yang dijalankan.

aws omics get-run \ --id 1234567

Output:

{ "arn": "arn:aws:omics:us-west-2:123456789012:run/1234567", "creationTime": "2022-11-30T22:58:22.615865Z", "digest": "sha256:c54bxmpl742dcc26f7fa1f10e37550ddd8f251f418277c0a58e895b801ed28cf", "id": "1234567", "name": "cram-to-bam", "outputUri": "s3://omics-artifacts-01d6xmpl4e72dd32/workflow-output/", "parameters": { "ref_dict": "s3://omics-artifacts-01d6xmpl4e72dd32/Homo_sapiens_assembly38.dict", "ref_fasta_index": "s3://omics-artifacts-01d6xmpl4e72dd32/Homo_sapiens_assembly38.fasta.fai", "ref_fasta": "s3://omics-artifacts-01d6xmpl4e72dd32/Homo_sapiens_assembly38.fasta", "sample_name": "NA12878", "input_cram": "s3://omics-artifacts-01d6xmpl4e72dd32/NA12878.cram" }, "resourceDigests": { "s3://omics-artifacts-01d6xmpl4e72dd32/Homo_sapiens_assembly38.fasta.fai": "etag:f76371b113734a56cde236bc0372de0a", "s3://omics-artifacts-01d6xmpl4e72dd32/Homo_sapiens_assembly38.dict": "etag:3884c62eb0e53fa92459ed9bff133ae6", "s3://omics-artifacts-01d6xmpl4e72dd32/Homo_sapiens_assembly38.fasta": "etag:e307d81c605fb91b7720a08f00276842-388", "s3://omics-artifacts-01d6xmpl4e72dd32/NA12878.cram": "etag:a9f52976381286c6143b5cc681671ec6" }, "roleArn": "arn:aws:iam::123456789012:role/omics-service-role-serviceRole-W8O1XMPL7QZ", "startedBy": "arn:aws:iam::123456789012:user/laptop-2020", "status": "STARTING", "tags": {}, "workflowId": "1234567", "workflowType": "PRIVATE" }

Untuk informasi selengkapnya, lihat Menjalankan siklus hidup dalam alur kerja di Panduan AWS HealthOmics Pengguna.

  • Untuk detail API, lihat GetRun di Refer AWS CLI ensi Perintah.

Contoh kode berikut menunjukkan cara menggunakanget-sequence-store.

AWS CLI

Untuk melihat penyimpanan urutan

get-sequence-storeContoh berikut mendapatkan detail tentang penyimpanan urutan dengan ID1234567890.

aws omics get-sequence-store \ --id 1234567890

Output:

{ "arn": "arn:aws:omics:us-east-1:123456789012:sequenceStore/1234567890", "creationTime": "2022-11-23T19:55:48.376Z", "id": "1234567890", "name": "my-seq-store" }

Untuk informasi selengkapnya, lihat Peny impanan Omics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanget-share.

AWS CLI

Untuk mengambil metadata tentang bagian dari data HealthOmics analitik

get-shareContoh berikut mengambil metadata untuk berbagi data analitik lintas akun.

aws omics get-share \ --share-id "495c21bedc889d07d0ab69d710a6841e-dd75ab7a1a9c384fa848b5bd8e5a7e0a"

Output:

{ "share": { "shareId": "495c21bedc889d07d0ab69d710a6841e-dd75ab7a1a9c384fa848b5bd8e5a7e0a", "name": "my_Share-123", "resourceArn": "arn:aws:omics:us-west-2:555555555555:variantStore/omics_dev_var_store", "principalSubscriber": "123456789012", "ownerId": "555555555555", "status": "PENDING" } }

Untuk informasi selengkapnya, lihat Cross-account berbagi di Panduan AWS HealthOmics Pengguna.

  • Untuk detail API, lihat GetShare di Refer AWS CLI ensi Perintah.

Contoh kode berikut menunjukkan cara menggunakanget-variant-import-job.

AWS CLI

Untuk melihat pekerjaan impor varian

get-variant-import-jobContoh berikut mendapatkan detail tentang pekerjaan impor varian.

aws omics get-variant-import-job \ --job-id edd7b8ce-xmpl-47e2-bc99-258cac95a508

Output:

{ "creationTime": "2022-11-23T22:42:50.037812Z", "destinationName": "my_var_store", "id": "edd7b8ce-xmpl-47e2-bc99-258cac95a508", "items": [ { "jobStatus": "IN_PROGRESS", "source": "s3://omics-artifacts-01d6xmpl4e72dd32/Homo_sapiens_assembly38.known_indels.vcf.gz" } ], "roleArn": "arn:aws:iam::123456789012:role/omics-service-role-serviceRole-W8O1XMPL7QZ", "runLeftNormalization": false, "status": "IN_PROGRESS", "updateTime": "2022-11-23T22:43:05.898309Z" }

Untuk informasi selengkapnya, lihat Omics Analytics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanget-variant-store.

AWS CLI

Untuk melihat toko varian

get-variant-storeContoh berikut mendapatkan detail tentang toko varian.

aws omics get-variant-store \ --name my_var_store

Output:

{ "creationTime": "2022-11-23T22:09:07.534499Z", "id": "02dexmplcfdd", "name": "my_var_store", "reference": { "referenceArn": "arn:aws:omics:us-west-2:123456789012:referenceStore/1234567890/reference/1234567890" }, "status": "CREATING", "storeArn": "arn:aws:omics:us-west-2:123456789012:variantStore/my_var_store", "storeSizeBytes": 0, "tags": {}, "updateTime": "2022-11-23T22:09:24.931711Z" }

Untuk informasi selengkapnya, lihat Omics Analytics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanget-workflow.

AWS CLI

Untuk melihat alur kerja

get-workflowContoh berikut mendapatkan detail tentang alur kerja dengan ID1234567.

aws omics get-workflow \ --id 1234567

Output:

{ "arn": "arn:aws:omics:us-west-2:123456789012:workflow/1234567", "creationTime": "2022-11-30T22:33:16.225368Z", "digest": "sha256:c54bxmpl742dcc26f7fa1f10e37550ddd8f251f418277c0a58e895b801ed28cf", "engine": "WDL", "id": "1234567", "main": "workflow-crambam.wdl", "name": "cram-converter", "parameterTemplate": { "ref_dict": { "description": "dictionary file for 'ref_fasta'" }, "ref_fasta_index": { "description": "Index of the reference genome fasta file" }, "ref_fasta": { "description": "Reference genome fasta file" }, "input_cram": { "description": "The Cram file to convert to BAM" }, "sample_name": { "description": "The name of the input sample, used to name the output BAM" } }, "status": "ACTIVE", "statusMessage": "workflow-crambam.wdl\n workflow CramToBamFlow\n call CramToBamTask\n call ValidateSamFile\n task CramToBamTask\n task ValidateSamFile\n", "tags": {}, "type": "PRIVATE" }

Untuk informasi selengkapnya, lihat Membuat alur kerja pribadi di Panduan AWS HealthOmics Pengguna.

  • Untuk detail API, lihat GetWorkflow di Refer AWS CLI ensi Perintah.

Contoh kode berikut menunjukkan cara menggunakanlist-annotation-import-jobs.

AWS CLI

Untuk mendapatkan daftar pekerjaan impor anotasi

Berikut ini list-annotation-import-jobs mendapatkan daftar pekerjaan impor anotasi.

aws omics list-annotation-import-jobs

Output:

{ "annotationImportJobs": [ { "creationTime": "2022-11-30T01:39:41.478294Z", "destinationName": "gff_ann_store", "id": "18a9e792-xmpl-4869-a105-e5b602900444", "roleArn": "arn:aws:iam::123456789012:role/omics-service-role-serviceRole-W8O1XMPL7QZ", "runLeftNormalization": false, "status": "COMPLETED", "updateTime": "2022-11-30T01:47:09.145178Z" }, { "creationTime": "2022-11-30T00:45:58.007838Z", "destinationName": "my_ann_store", "id": "4e9eafc8-xmpl-431e-a0b2-3bda27cb600a", "roleArn": "arn:aws:iam::123456789012:role/omics-service-role-serviceRole-W8O1XMPL7QZ", "runLeftNormalization": false, "status": "FAILED", "updateTime": "2022-11-30T00:47:01.706325Z" } ] }

Untuk informasi selengkapnya, lihat Omics Analytics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanlist-annotation-store-versions.

AWS CLI

Untuk mencantumkan semua versi toko anotasi.

list-annotation-store-versionsContoh berikut mencantumkan semua versi yang ada dari penyimpanan anotasi.

aws omics list-annotation-store-versions \ --name my_annotation_store

Output:

{ "annotationStoreVersions": [ { "storeId": "4934045d1c6d", "id": "2a3f4a44aa7b", "status": "CREATING", "versionArn": "arn:aws:omics:us-west-2:555555555555:annotationStore/my_annotation_store/version/my_version_2", "name": "my_annotation_store", "versionName": "my_version_2", "creation Time": "2023-07-21T17:20:59.380043+00:00", "versionSizeBytes": 0 }, { "storeId": "4934045d1c6d", "id": "4934045d1c6d", "status": "ACTIVE", "versionArn": "arn:aws:omics:us-west-2:555555555555:annotationStore/my_annotation_store/version/my_version_1", "name": "my_annotation_store", "versionName": "my_version_1", "creationTime": "2023-07-21T17:15:49.251040+00:00", "updateTime": "2023-07-21T17:15:56.434223+00:00", "statusMessage": "", "versionSizeBytes": 0 } }

Untuk informasi selengkapnya, lihat Membuat versi baru penyimpanan anotasi di Panduan AWS HealthOmics Pengguna.

Contoh kode berikut menunjukkan cara menggunakanlist-annotation-stores.

AWS CLI

Untuk mendapatkan daftar toko anotasi

list-annotation-storesContoh berikut mendapatkan daftar toko anotasi.

aws omics list-annotation-stores

Output:

{ "annotationStores": [ { "creationTime": "2022-11-23T22:48:39.226492Z", "id": "0a91xmplc71f", "name": "my_ann_store", "reference": { "referenceArn": "arn:aws:omics:us-west-2:123456789012:referenceStore/1234567890/reference/1234567890" }, "status": "ACTIVE", "statusMessage": "", "storeArn": "arn:aws:omics:us-west-2:123456789012:annotationStore/my_ann_store", "storeFormat": "VCF", "storeSizeBytes": 0, "updateTime": "2022-11-23T22:53:27.372840Z" } ] }

Untuk informasi selengkapnya, lihat Omics Analytics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanlist-multipart-read-set-uploads.

AWS CLI

Untuk mencantumkan semua unggahan kumpulan baca multibagian dan statusnya.

list-multipart-read-set-uploadsContoh berikut mencantumkan semua unggahan kumpulan baca multibagian dan statusnya.

aws omics list-multipart-read-set-uploads \ --sequence-store-id 0123456789

Output:

{ "uploads": [ { "sequenceStoreId": "0123456789", "uploadId": "8749584421", "sourceFileType": "FASTQ", "subjectId": "mySubject", "sampleId": "mySample", "generatedFrom": "1000 Genomes", "name": "HG00146", "description": "FASTQ for HG00146", "creationTime": "2023-11-29T19:22:51.349298+00:00" }, { "sequenceStoreId": "0123456789", "uploadId": "5290538638", "sourceFileType": "BAM", "subjectId": "mySubject", "sampleId": "mySample", "generatedFrom": "1000 Genomes", "referenceArn": "arn:aws:omics:us-west-2:845448930428:referenceStore/8168613728/reference/2190697383", "name": "HG00146", "description": "BAM for HG00146", "creationTime": "2023-11-29T19:23:33.116516+00:00" }, { "sequenceStoreId": "0123456789", "uploadId": "4174220862", "sourceFileType": "BAM", "subjectId": "mySubject", "sampleId": "mySample", "generatedFrom": "1000 Genomes", "referenceArn": "arn:aws:omics:us-west-2:845448930428:referenceStore/8168613728/reference/2190697383", "name": "HG00147", "description": "BAM for HG00147", "creationTime": "2023-11-29T19:23:47.007866+00:00" } ] }

Untuk informasi selengkapnya, lihat Mengunggah langsung ke penyimpanan urutan di Panduan AWS HealthOmics Pengguna.

Contoh kode berikut menunjukkan cara menggunakanlist-read-set-activation-jobs.

AWS CLI

Untuk mendapatkan daftar pekerjaan aktivasi set baca

list-read-set-activation-jobsContoh berikut mendapatkan daftar pekerjaan aktivasi untuk penyimpanan urutan dengan id1234567890.

aws omics list-read-set-activation-jobs \ --sequence-store-id 1234567890

Output:

{ "activationJobs": [ { "completionTime": "2022-12-06T22:33:42.828Z", "creationTime": "2022-12-06T22:32:45.213Z", "id": "1234567890", "sequenceStoreId": "1234567890", "status": "COMPLETED" }, { "creationTime": "2022-12-06T22:35:10.100Z", "id": "1234567890", "sequenceStoreId": "1234567890", "status": "IN_PROGRESS" } ] }

Untuk informasi selengkapnya, lihat Peny impanan Omics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanlist-read-set-export-jobs.

AWS CLI

Untuk mendapatkan daftar tugas ekspor set baca

list-read-set-export-jobsContoh berikut mendapatkan daftar pekerjaan ekspor untuk penyimpanan urutan dengan id1234567890.

aws omics list-read-set-export-jobs \ --sequence-store-id 1234567890

Output:

{ "exportJobs": [ { "completionTime": "2022-12-06T22:39:14.491Z", "creationTime": "2022-12-06T22:37:18.612Z", "destination": "s3://omics-artifacts-01d6xmpl4e72dd32/read-set-export/", "id": "1234567890", "sequenceStoreId": "1234567890", "status": "COMPLETED" }, { "creationTime": "2022-12-06T22:38:04.871Z", "destination": "s3://omics-artifacts-01d6xmpl4e72dd32/read-set-export/", "id": "1234567890", "sequenceStoreId": "1234567890", "status": "IN_PROGRESS" } ] }

Untuk informasi selengkapnya, lihat Peny impanan Omics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanlist-read-set-import-jobs.

AWS CLI

Untuk mendapatkan daftar tugas impor set baca

list-read-set-import-jobsContoh berikut mendapatkan daftar pekerjaan impor untuk penyimpanan urutan dengan id1234567890.

aws omics list-read-set-import-jobs \ --sequence-store-id 1234567890

Output:

{ "importJobs": [ { "completionTime": "2022-11-29T18:17:49.244Z", "creationTime": "2022-11-29T17:32:47.700Z", "id": "1234567890", "roleArn": "arn:aws:iam::123456789012:role/omics-service-role-serviceRole-W8O1XMPL7QZ", "sequenceStoreId": "1234567890", "status": "COMPLETED" }, { "completionTime": "2022-11-23T22:01:34.090Z", "creationTime": "2022-11-23T21:52:43.289Z", "id": "1234567890", "roleArn": "arn:aws:iam::123456789012:role/omics-service-role-serviceRole-W8O1XMPL7QZ", "sequenceStoreId": "1234567890", "status": "COMPLETED_WITH_FAILURES" } ] }

Untuk informasi selengkapnya, lihat Peny impanan Omics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanlist-read-set-upload-parts.

AWS CLI

Untuk mencantumkan semua bagian dalam unggahan multipart yang diminta untuk penyimpanan urutan.

list-read-set-upload-partsContoh berikut mencantumkan semua bagian dalam unggahan multipart yang diminta untuk penyimpanan urutan.

aws omics list-read-set-upload-parts \ --sequence-store-id 0123456789 \ --upload-id 1122334455 \ --part-source SOURCE1

Output:

{ "parts": [ { "partNumber": 1, "partSize": 94371840, "file": "SOURCE1", "checksum": "984979b9928ae8d8622286c4a9cd8e99d964a22d59ed0f5722e1733eb280e635", "lastUpdatedTime": "2023-02-02T20:14:47.533000+00:00" } { "partNumber": 2, "partSize": 10471840, "file": "SOURCE1", "checksum": "984979b9928ae8d8622286c4a9cd8e99d964a22d59ed0f5722e1733eb280e635", "lastUpdatedTime": "2023-02-02T20:14:47.533000+00:00" } ] }

Untuk informasi selengkapnya, lihat Mengunggah langsung ke penyimpanan urutan di Panduan AWS HealthOmics Pengguna.

Contoh kode berikut menunjukkan cara menggunakanlist-read-sets.

AWS CLI

Untuk mendapatkan daftar set baca

list-read-setsContoh berikut mendapatkan daftar set baca untuk penyimpanan urutan dengan id1234567890.

aws omics list-read-sets \ --sequence-store-id 1234567890

Output:

{ "readSets": [ { "arn": "arn:aws:omics:us-west-2:123456789012:sequenceStore/1234567890/readSet/1234567890", "creationTime": "2022-11-23T21:55:00.515Z", "fileType": "FASTQ", "id": "1234567890", "name": "HG00146", "referenceArn": "arn:aws:omics:us-west-2:123456789012:referenceStore/1234567890/reference/1234567890", "sampleId": "fastq-sample", "sequenceStoreId": "1234567890", "status": "ACTIVE", "subjectId": "fastq-subject" } ] }

Untuk informasi selengkapnya, lihat Peny impanan Omics di Panduan Pengembang Amazon Omics.

  • Untuk detail API, lihat ListReadSets di Refer AWS CLI ensi Perintah.

Contoh kode berikut menunjukkan cara menggunakanlist-reference-import-jobs.

AWS CLI

Untuk mendapatkan daftar pekerjaan impor referensi

list-reference-import-jobsContoh berikut mendapatkan daftar pekerjaan impor referensi untuk toko referensi dengan id1234567890.

aws omics list-reference-import-jobs \ --reference-store-id 1234567890

Output:

{ "importJobs": [ { "completionTime": "2022-11-23T19:54:58.204Z", "creationTime": "2022-11-23T19:53:20.729Z", "id": "1234567890", "referenceStoreId": "1234567890", "roleArn": "arn:aws:iam::123456789012:role/omics-service-role-serviceRole-W8O1XMPL7QZ", "status": "COMPLETED" }, { "creationTime": "2022-11-23T20:34:03.250Z", "id": "1234567890", "referenceStoreId": "1234567890", "roleArn": "arn:aws:iam::123456789012:role/omics-service-role-serviceRole-W8O1XMPL7QZ", "status": "IN_PROGRESS" } ] }

Untuk informasi selengkapnya, lihat Peny impanan Omics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanlist-reference-stores.

AWS CLI

Untuk mendapatkan daftar toko referensi

list-reference-storesContoh berikut mendapatkan daftar toko referensi.

aws omics list-reference-stores

Output:

{ "referenceStores": [ { "arn": "arn:aws:omics:us-west-2:123456789012:referenceStore/1234567890", "creationTime": "2022-11-22T22:13:25.947Z", "id": "1234567890", "name": "my-ref-store" } ] }

Untuk informasi selengkapnya, lihat Peny impanan Omics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanlist-references.

AWS CLI

Untuk mendapatkan daftar referensi

list-referencesContoh berikut mendapatkan daftar referensi genom untuk penyimpanan referensi dengan id1234567890.

aws omics list-references \ --reference-store-id 1234567890

Output:

{ "references": [ { "arn": "arn:aws:omics:us-west-2:123456789012:referenceStore/1234567890/reference/1234567890", "creationTime": "2022-11-22T22:27:09.033Z", "id": "1234567890", "md5": "7ff134953dcca8c8997453bbb80b6b5e", "name": "assembly-38", "referenceStoreId": "1234567890", "status": "ACTIVE", "updateTime": "2022-11-22T22:27:09.033Z" } ] }

Untuk informasi selengkapnya, lihat Peny impanan Omics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanlist-run-groups.

AWS CLI

Untuk mendapatkan daftar grup yang dijalankan

list-run-groupsContoh berikut mendapatkan daftar grup run.

aws omics list-run-groups

Output:

{ "items": [ { "arn": "arn:aws:omics:us-west-2:123456789012:runGroup/1234567", "creationTime": "2022-12-01T00:58:42.915219Z", "id": "1234567", "maxCpus": 20, "maxDuration": 600, "name": "cram-convert" } ] }

Untuk informasi selengkapnya, lihat Membuat grup run di Panduan AWS HealthOmics Pengguna.

Contoh kode berikut menunjukkan cara menggunakanlist-run-tasks.

AWS CLI

Untuk mendapatkan daftar tugas

list-run-tasksContoh berikut mendapatkan daftar tugas untuk menjalankan alur kerja.

aws omics list-run-tasks \ --id 1234567

Output:

{ "items": [ { "cpus": 1, "creationTime": "2022-11-30T23:13:00.718651Z", "memory": 15, "name": "CramToBamTask", "startTime": "2022-11-30T23:17:47.016Z", "status": "COMPLETED", "stopTime": "2022-11-30T23:18:21.503Z", "taskId": "1234567" }, { "cpus": 1, "creationTime": "2022-11-30T23:18:32.315606Z", "memory": 4, "name": "ValidateSamFile", "startTime": "2022-11-30T23:23:40.165Z", "status": "COMPLETED", "stopTime": "2022-11-30T23:24:14.766Z", "taskId": "1234567" } ] }

Untuk informasi selengkapnya, lihat Siklus hidup HealthOmics tugas dalam proses di Panduan AWS HealthOmics Pengguna.

  • Untuk detail API, lihat ListRunTasks di Refer AWS CLI ensi Perintah.

Contoh kode berikut menunjukkan cara menggunakanlist-runs.

AWS CLI

Untuk mendapatkan daftar alur kerja yang dijalankan

list-runsContoh berikut mendapatkan daftar alur kerja yang dijalankan.

aws omics list-runs

Output:

{ "items": [ { "arn": "arn:aws:omics:us-west-2:123456789012:run/1234567", "creationTime": "2022-12-02T23:20:01.202074Z", "id": "1234567", "name": "cram-to-bam", "priority": 1, "startTime": "2022-12-02T23:29:18.115Z", "status": "COMPLETED", "stopTime": "2022-12-02T23:57:54.428812Z", "storageCapacity": 10, "workflowId": "1234567" }, { "arn": "arn:aws:omics:us-west-2:123456789012:run/1234567", "creationTime": "2022-12-03T00:16:57.180066Z", "id": "1234567", "name": "cram-to-bam", "priority": 1, "startTime": "2022-12-03T00:26:50.233Z", "status": "FAILED", "stopTime": "2022-12-03T00:37:21.451340Z", "storageCapacity": 10, "workflowId": "1234567" }, { "arn": "arn:aws:omics:us-west-2:123456789012:run/1234567", "creationTime": "2022-12-05T17:57:08.444817Z", "id": "1234567", "name": "cram-to-bam", "status": "STARTING", "workflowId": "1234567" } ] }

Untuk informasi selengkapnya, lihat Menjalankan siklus hidup dalam alur kerja di Panduan AWS HealthOmics Pengguna.

  • Untuk detail API, lihat ListRuns di Refer AWS CLI ensi Perintah.

Contoh kode berikut menunjukkan cara menggunakanlist-sequence-stores.

AWS CLI

Untuk mendapatkan daftar penyimpanan urutan

list-sequence-storesContoh berikut mendapatkan daftar penyimpanan urutan.

aws omics list-sequence-stores

Output:

{ "sequenceStores": [ { "arn": "arn:aws:omics:us-west-2:123456789012:sequenceStore/1234567890", "creationTime": "2022-11-23T01:24:33.629Z", "id": "1234567890", "name": "my-seq-store" } ] }

Untuk informasi selengkapnya, lihat Peny impanan Omics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanlist-shares.

AWS CLI

Untuk membuat daftar saham yang tersedia dari data HealthOmics analitik

list-sharesContoh berikut mencantumkan semua saham yang telah dibuat untuk pemilik sumber daya.

aws omics list-shares \ --resource-owner SELF

Output:

{ "shares": [ { "shareId": "595c1cbd-a008-4eca-a887-954d30c91c6e", "name": "myShare", "resourceArn": "arn:aws:omics:us-west-2:555555555555:variantStore/store_1", "principalSubscriber": "123456789012", "ownerId": "555555555555", "status": "PENDING" } { "shareId": "39b65d0d-4368-4a19-9814-b0e31d73c10a", "name": "myShare3456", "resourceArn": "arn:aws:omics:us-west-2:555555555555:variantStore/store_2", "principalSubscriber": "123456789012", "ownerId": "555555555555", "status": "ACTIVE" }, { "shareId": "203152f5-eef9-459d-a4e0-a691668d44ef", "name": "myShare4", "resourceArn": "arn:aws:omics:us-west-2:555555555555:variantStore/store_3", "principalSubscriber": "123456789012", "ownerId": "555555555555", "status": "ACTIVE" } ] }

Untuk informasi selengkapnya, lihat Cross-account berbagi di Panduan AWS HealthOmics Pengguna.

  • Untuk detail API, lihat ListShares di Refer AWS CLI ensi Perintah.

Contoh kode berikut menunjukkan cara menggunakanlist-tags-for-resource.

AWS CLI

Untuk mendapatkan daftar tag

list-tags-for-resourceContoh berikut mendapatkan daftar tag untuk alur kerja dengan id1234567.

aws omics list-tags-for-resource \ --resource-arn arn:aws:omics:us-west-2:123456789012:workflow/1234567

Output:

{ "tags": { "department": "analytics" } }

Untuk informasi selengkapnya, lihat Men andai sumber daya di Amazon Omics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanlist-variant-import-jobs.

AWS CLI

Untuk mendapatkan daftar pekerjaan impor varian

list-variant-import-jobsContoh berikut mendapatkan daftar pekerjaan impor varian.

aws omics list-variant-import-jobs

Output:

{ "variantImportJobs": [ { "creationTime": "2022-11-23T22:47:02.514002Z", "destinationName": "my_var_store", "id": "69cb65d6-xmpl-4a4a-9025-4565794b684e", "roleArn": "arn:aws:iam::123456789012:role/omics-service-role-serviceRole-W8O1XMPL7QZ", "runLeftNormalization": false, "status": "COMPLETED", "updateTime": "2022-11-23T22:49:17.976597Z" }, { "creationTime": "2022-11-23T22:42:50.037812Z", "destinationName": "my_var_store", "id": "edd7b8ce-xmpl-47e2-bc99-258cac95a508", "roleArn": "arn:aws:iam::123456789012:role/omics-service-role-serviceRole-W8O1XMPL7QZ", "runLeftNormalization": false, "status": "COMPLETED", "updateTime": "2022-11-23T22:45:26.009880Z" } ] }

Untuk informasi selengkapnya, lihat Omics Analytics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanlist-variant-stores.

AWS CLI

Untuk mendapatkan daftar toko varian

list-variant-storesContoh berikut mendapatkan daftar toko varian.

aws omics list-variant-stores

Output:

{ "variantStores": [ { "creationTime": "2022-11-23T22:09:07.534499Z", "id": "02dexmplcfdd", "name": "my_var_store", "reference": { "referenceArn": "arn:aws:omics:us-west-2:123456789012:referenceStore/1234567890/reference/1234567890" }, "status": "CREATING", "storeArn": "arn:aws:omics:us-west-2:123456789012:variantStore/my_var_store", "storeSizeBytes": 0, "updateTime": "2022-11-23T22:09:24.931711Z" }, { "creationTime": "2022-09-23T23:00:09.140265Z", "id": "8777xmpl1a24", "name": "myvstore0", "status": "ACTIVE", "storeArn": "arn:aws:omics:us-west-2:123456789012:variantStore/myvstore0", "storeSizeBytes": 0, "updateTime": "2022-09-23T23:03:26.013220Z" } ] }

Untuk informasi selengkapnya, lihat Omics Analytics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanlist-workflows.

AWS CLI

Untuk mendapatkan daftar alur kerja

list-workflowsContoh berikut mendapatkan daftar alur kerja.

aws omics list-workflows

Output:

{ "items": [ { "arn": "arn:aws:omics:us-west-2:123456789012:workflow/1234567", "creationTime": "2022-09-23T23:08:22.041227Z", "digest": "nSCNo/qMWFxmplXpUdokXJnwgneOaxyyc2YOxVxrJTE=", "id": "1234567", "name": "my-wkflow-0", "status": "ACTIVE", "type": "PRIVATE" }, { "arn": "arn:aws:omics:us-west-2:123456789012:workflow/1234567", "creationTime": "2022-11-30T22:33:16.225368Z", "digest": "sha256:c54bxmpl742dcc26f7fa1f10e37550ddd8f251f418277c0a58e895b801ed28cf", "id": "1234567", "name": "cram-converter", "status": "ACTIVE", "type": "PRIVATE" } ] }

Untuk informasi selengkapnya, lihat Membuat alur kerja pribadi di Panduan AWS HealthOmics Pengguna.

Contoh kode berikut menunjukkan cara menggunakanstart-annotation-import-job.

AWS CLI

Untuk mengimpor anotasi

start-annotation-import-jobContoh berikut mengimpor anotasi dari Amazon S3.

aws omics start-annotation-import-job \ --destination-name tsv_ann_store \ --no-run-left-normalization \ --role-arn arn:aws:iam::123456789012:role/omics-service-role-serviceRole-W8O1XMPL7QZ \ --items source=s3://omics-artifacts-01d6xmpl4e72dd32/targetedregions.bed.gz

Output:

{ "jobId": "984162c7-xmpl-4d23-ab47-286f7950bfbf" }

Untuk informasi selengkapnya, lihat Omics Analytics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanstart-read-set-activation-job.

AWS CLI

Untuk mengaktifkan kumpulan baca yang diarsipkan

start-read-set-activation-jobContoh berikut mengaktifkan dua set baca.

aws omics start-read-set-activation-job \ --sequence-store-id 1234567890 \ --sources readSetId=1234567890 readSetId=1234567890

Output:

{ "creationTime": "2022-12-06T22:35:10.100Z", "id": "1234567890", "sequenceStoreId": "1234567890", "status": "SUBMITTED" }

Untuk informasi selengkapnya, lihat Peny impanan Omics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanstart-read-set-export-job.

AWS CLI

Untuk mengekspor kumpulan baca

start-read-set-export-jobContoh berikut mengekspor dua set baca ke Amazon S3.

aws omics start-read-set-export-job \ --sequence-store-id 1234567890 \ --sources readSetId=1234567890 readSetId=1234567890 \ --role-arn arn:aws:iam::123456789012:role/omics-service-role-serviceRole-W8O1XMPL7QZ \ --destination s3://omics-artifacts-01d6xmpl4e72dd32/read-set-export/

Output:

{ "creationTime": "2022-12-06T22:37:18.612Z", "destination": "s3://omics-artifacts-01d6xmpl4e72dd32/read-set-export/", "id": "1234567890", "sequenceStoreId": "1234567890", "status": "SUBMITTED" }

Untuk informasi selengkapnya, lihat Peny impanan Omics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanstart-read-set-import-job.

AWS CLI

Untuk mengimpor kumpulan baca

start-read-set-import-jobContoh berikut mengimpor kumpulan baca.

aws omics start-read-set-import-job \ --sequence-store-id 1234567890 \ --role-arn arn:aws:iam::123456789012:role/omics-service-role-serviceRole-W8O1XMPL7QZ \ --sources file://readset-sources.json

readset-sources.json adalah dokumen JSON dengan konten berikut.

[ { "sourceFiles": { "source1": "s3://omics-artifacts-01d6xmpl4e72dd32/HG00100.chrom20.ILLUMINA.bwa.GBR.low_coverage.20101123.bam" }, "sourceFileType": "BAM", "subjectId": "bam-subject", "sampleId": "bam-sample", "referenceArn": "arn:aws:omics:us-west-2:123456789012:referenceStore/1234567890/reference/1234567890", "name": "HG00100" } ]

Output:

{ "creationTime": "2022-11-23T01:36:38.158Z", "id": "1234567890", "roleArn": "arn:aws:iam::123456789012:role/omics-service-role-serviceRole-W8O1XMPL7QZ", "sequenceStoreId": "1234567890", "status": "SUBMITTED" }

Untuk informasi selengkapnya, lihat Peny impanan Omics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanstart-reference-import-job.

AWS CLI

Untuk mengimpor genom referensi

start-reference-import-jobContoh berikut mengimpor genom referensi dari Amazon S3.

aws omics start-reference-import-job \ --reference-store-id 1234567890 \ --role-arn arn:aws:iam::123456789012:role/omics-service-role-serviceRole-W8O1XMPL7QZ \ --sources sourceFile=s3://omics-artifacts-01d6xmpl4e72dd32/Homo_sapiens_assembly38.fasta,name=assembly-38

Output:

{ "creationTime": "2022-11-22T22:25:41.124Z", "id": "1234567890", "referenceStoreId": "1234567890", "roleArn": "arn:aws:iam::123456789012:role/omics-service-role-serviceRole-W8O1XMPL7QZ", "status": "SUBMITTED" }

Untuk informasi selengkapnya, lihat Peny impanan Omics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanstart-run.

AWS CLI

Untuk menjalankan alur kerja

start-runContoh berikut menjalankan alur kerja dengan ID1234567.

aws omics start-run \ --workflow-id 1234567 \ --role-arn arn:aws:iam::123456789012:role/omics-service-role-serviceRole-W8O1XMPL7QZ \ --name 'cram-to-bam' \ --output-uri s3://omics-artifacts-01d6xmpl4e72dd32/workflow-output/ \ --run-group-id 1234567 \ --priority 1 \ --storage-capacity 10 \ --log-level ALL \ --parameters file://workflow-inputs.json

workflow-inputs.json adalah dokumen JSON dengan konten berikut.

{ "sample_name": "NA12878", "input_cram": "s3://omics-artifacts-01d6xmpl4e72dd32/NA12878.cram", "ref_dict": "s3://omics-artifacts-01d6xmpl4e72dd32/Homo_sapiens_assembly38.dict", "ref_fasta": "s3://omics-artifacts-01d6xmpl4e72dd32/Homo_sapiens_assembly38.fasta", "ref_fasta_index": "omics-artifacts-01d6xmpl4e72dd32/Homo_sapiens_assembly38.fasta.fai" }

Output:

{ "arn": "arn:aws:omics:us-west-2:123456789012:run/1234567", "id": "1234567", "status": "PENDING", "tags": {} }

Untuk informasi selengkapnya, lihat Mem ulai menjalankan di Panduan AWS HealthOmics Pengguna.

Untuk memuat file sumber dari Amazon Omics

Anda juga dapat memuat file sumber dari penyimpanan Amazon Omics, dengan menggunakan URI khusus layanan. Contoh file workflow-inputs.json berikut menggunakan URI Amazon Omics untuk kumpulan baca dan referensi sumber genom.

{ "sample_name": "NA12878", "input_cram": "omics://123456789012.storage.us-west-2.amazonaws.com/1234567890/readSet/1234567890/source1", "ref_dict": "s3://omics-artifacts-01d6xmpl4e72dd32/Homo_sapiens_assembly38.dict", "ref_fasta": "omics://123456789012.storage.us-west-2.amazonaws.com/1234567890/reference/1234567890", "ref_fasta_index": "omics://123456789012.storage.us-west-2.amazonaws.com/1234567890/reference/1234567890/index" }
  • Untuk detail API, lihat StartRun di Refer AWS CLI ensi Perintah.

Contoh kode berikut menunjukkan cara menggunakanstart-variant-import-job.

AWS CLI

Untuk mengimpor file varian

start-variant-import-jobContoh berikut mengimpor file varian format VCF.

aws omics start-variant-import-job \ --destination-name my_var_store \ --no-run-left-normalization \ --role-arn arn:aws:iam::123456789012:role/omics-service-role-serviceRole-W8O1XMPL7QZ \ --items source=s3://omics-artifacts-01d6xmpl4e72dd32/Homo_sapiens_assembly38.known_indels.vcf.gz

Output:

{ "jobId": "edd7b8ce-xmpl-47e2-bc99-258cac95a508" }

Untuk informasi selengkapnya, lihat Omics Analytics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakantag-resource.

AWS CLI

Untuk menandai sumber daya

tag-resourceContoh berikut menambahkan department tag ke alur kerja dengan id1234567.

aws omics tag-resource \ --resource-arn arn:aws:omics:us-west-2:123456789012:workflow/1234567 \ --tags department=analytics

Untuk informasi selengkapnya, lihat Men andai sumber daya di Amazon Omics di Panduan Pengembang Amazon Omics.

  • Untuk detail API, lihat TagResource di Refer AWS CLI ensi Perintah.

Contoh kode berikut menunjukkan cara menggunakanuntag-resource.

AWS CLI

Untuk menghapus tag dari sumber daya

untag-resourceContoh berikut menghapus department tag dari alur kerja.

aws omics untag-resource \ --resource-arn arn:aws:omics:us-west-2:123456789012:workflow/1234567 \ --tag-keys department

Untuk informasi selengkapnya, lihat Peny impanan Omics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanupdate-annotation-store.

AWS CLI

Untuk memperbarui penyimpanan anotasi

update-annotation-storeContoh berikut memperbarui deskripsi toko anotasi bernamamy_vcf_store.

aws omics update-annotation-store \ --name my_vcf_store \ --description "VCF annotation store"

Output:

{ "creationTime": "2022-12-05T18:00:56.101860Z", "description": "VCF annotation store", "id": "bd6axmpl2444", "name": "my_vcf_store", "reference": { "referenceArn": "arn:aws:omics:us-west-2:123456789012:referenceStore/1234567890/reference/1234567890" }, "status": "ACTIVE", "storeFormat": "VCF", "updateTime": "2022-12-05T18:13:16.100051Z" }

Untuk informasi selengkapnya, lihat Omics Analytics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanupdate-run-group.

AWS CLI

Untuk memperbarui grup yang dijalankan

update-run-groupContoh berikut memperbarui pengaturan grup run dengan id1234567.

aws omics update-run-group \ --id 1234567 \ --max-cpus 10

Output:

{ "arn": "arn:aws:omics:us-west-2:123456789012:runGroup/1234567", "creationTime": "2022-12-01T00:58:42.915219Z", "id": "1234567", "maxCpus": 10, "maxDuration": 600, "name": "cram-convert", "tags": {} }

Untuk informasi selengkapnya, lihat Alu r Kerja Omics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanupdate-variant-store.

AWS CLI

Untuk memperbarui penyimpanan varian

update-variant-storeContoh berikut memperbarui deskripsi toko varian bernamamy_var_store.

aws omics update-variant-store \ --name my_var_store \ --description "variant store"

Output:

{ "creationTime": "2022-11-23T22:09:07.534499Z", "description": "variant store", "id": "02dexmplcfdd", "name": "my_var_store", "reference": { "referenceArn": "arn:aws:omics:us-west-2:123456789012:referenceStore/1234567890/reference/1234567890" }, "status": "ACTIVE", "updateTime": "2022-12-05T18:23:37.686402Z" }

Untuk informasi selengkapnya, lihat Omics Analytics di Panduan Pengembang Amazon Omics.

Contoh kode berikut menunjukkan cara menggunakanupdate-workflow.

AWS CLI

Untuk memperbarui alur kerja

update-workflowContoh berikut memperbarui deskripsi alur kerja dengan ID1234567.

aws omics update-workflow \ --id 1234567 \ --description "copy workflow"

Untuk informasi selengkapnya, lihat Membuat atau memperbarui alur kerja di Panduan AWS HealthOmics Pengguna.

Contoh kode berikut menunjukkan cara menggunakanupload-read-set-part.

AWS CLI

Untuk mengunggah bagian set baca.

upload-read-set-partContoh berikut mengunggah bagian tertentu dari kumpulan baca.

aws omics upload-read-set-part \ --sequence-store-id 0123456789 \ --upload-id 1122334455 \ --part-source SOURCE1 \ --part-number 1 \ --payload /path/to/file/read_1_part_1.fastq.gz

Output:

{ "checksum": "984979b9928ae8d8622286c4a9cd8e99d964a22d59ed0f5722e1733eb280e635" }

Untuk informasi selengkapnya, lihat Mengunggah langsung ke penyimpanan urutan di Panduan AWS HealthOmics Pengguna.